==> pokerth_0.5+dfsg.orig.tar.gz: pokerth-0.5+dfsg/src/gui/qt/newlocalgamedialog/newgamedialogimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef NEWGAMEDIALOGIMPL_H
#define NEWGAMEDIALOGIMPL_H

#include "ui_newgamedialog.h"

#include <QtGui>
#include <QtCore>

class ConfigFile;

class newGameDialogImpl: public QDialog, public Ui::newGameDialog {
Q_OBJECT
public:
    newGameDialogImpl(QWidget *parent = 0, ConfigFile* = 0);

	void exec();

public slots:

private:
		
	ConfigFile *myConfig;	

};

#endif

==> pokerth_0.7.1.orig.tar.gz: pokerth-0.7.1/src/gui/qt/newlocalgamedialog/newgamedialogimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef NEWGAMEDIALOGIMPL_H
#define NEWGAMEDIALOGIMPL_H

#include "ui_newgamedialog.h"

#include <QtGui>
#include <QtCore>


class ConfigFile;
class changeCompleteBlindsDialogImpl;

class newGameDialogImpl: public QDialog, public Ui::newGameDialog {
Q_OBJECT
public:
    newGameDialogImpl(QMainWindow *parent = 0, ConfigFile* = 0);

	void exec();
	changeCompleteBlindsDialogImpl* getChangeCompleteBlindsDialog() { return myChangeCompleteBlindsDialog; }

public slots:

	void callChangeBlindsDialog(bool);

private:
		
	ConfigFile *myConfig;	
	changeCompleteBlindsDialogImpl *myChangeCompleteBlindsDialog;

};

#endif
